@@ -19,13 +19,10 @@
  * up when the menu item is selected. Typically, all menu items in a menu bar
  * have submenus.
  *
- * The GtkOptionMenu widget is a button that pops up a GtkMenu when clicked.
- * It's used inside dialogs and such.
- *
- * GtkItemFactory provides a higher-level interface for creating menu bars
+ * GtkUIManager provides a higher-level interface for creating menu bars
  * and menus; while you can construct menus manually, most people don't
- * do that. There's a separate demo for GtkItemFactory.
- * 
+ * do that. There's a separate demo for GtkUIManager.
+ *
  */
 
 #include "gtkmm.h"
@@ -100,7 +97,7 @@ Example_Menus::Example_Menus()
     MenuList items = pMenu->items();
 
     items.push_back(SeparatorElem());
-    items.push_back( CheckMenuElem("Accelerate Me", AccelKey(GDK_F1, Gdk::ModifierType(0))) );
+    items.push_back( CheckMenuElem("Accelerate Me", Gtk::AccelKey(GDK_F1, Gdk::ModifierType(0))) );
     items.push_back( CheckMenuElem("Accelerator Locked") );
     items.back().add_accelerator("activate", get_accel_group(), GDK_F2, Gdk::ModifierType(0), Gtk::ACCEL_VISIBLE | Gtk::ACCEL_LOCKED);
     items.push_back( CheckMenuElem("Accelerator Frozen") );
