@@ -136,10 +136,10 @@ Glib::RefPtr<Gtk::TreeModel> Example_StockBrowser::create_model()
 
   // obtain the ids of all stock items
   typedef std::vector<Gtk::StockID> type_vecIDs;
-  type_vecIDs vecIDs = Gtk::Stock::get_ids();
+  const type_vecIDs vecIDs = Gtk::Stock::get_ids();
 
   // iterate through them, populating the ListStore as appropriate
-  for(type_vecIDs::iterator iterIDs = vecIDs.begin(); iterIDs != vecIDs.end(); ++iterIDs)
+  for(type_vecIDs::const_iterator iterIDs = vecIDs.begin(); iterIDs != vecIDs.end(); ++iterIDs)
   {
     const Gtk::StockID& stockid = *iterIDs;
 
@@ -183,20 +183,7 @@ Glib::ustring Example_StockBrowser::id_to_symbol(const Gtk::StockID& stockid)
   if((id.length() >= prefix_length) && (id.compare(0, prefix_length, prefix) == 0))
   {
     scope = "Gtk::Stock::";
-
-    // This does not work with the SUN Forte compiler:
-    // "/opt/SUNWspro/WS6U2/include/CC/Cstd/rw/iterator", 
-    // line 331: Error: Could not find a match for 
-    // std::__iterator_category<std::T>(Glib::ustring_Iterator<const char*>).
-    // "example_stockbrowser.cc", line 186:     Where: While instantiating 
-    // "std::advance<Glib::ustring_Iterator<const char*>, unsigned>(Glib::ustring_Iterator<const char*>&, unsigned)".
-    // "example_stockbrowser.cc", line 186:     Where: Instantiated from non-template code.
-    //
-    // std::advance(id_pos, prefix_length);
-    //
-    // So we do this instead:
-    for(Glib::ustring::size_type i = 0; i < prefix_length; ++i)
-      ++id_pos;
+    std::advance(id_pos, prefix_length);
   }
 
   Glib::ustring symbol;
@@ -240,12 +227,12 @@ void Example_StockBrowser::on_selection_changed()
       const Gtk::IconSet iconset = Gtk::IconSet::lookup_default(stockid);
 
       typedef std::vector<Gtk::IconSize> type_vecSizes;
-      type_vecSizes sizes = iconset.get_sizes();
+      const type_vecSizes sizes = iconset.get_sizes();
 
       Gtk::IconSize best_size = Gtk::ICON_SIZE_INVALID;
       int biggest_pixelcount = 0;
 
-      for(type_vecSizes::iterator psize = sizes.begin(); psize != sizes.end(); ++psize)
+      for(type_vecSizes::const_iterator psize = sizes.begin(); psize != sizes.end(); ++psize)
       {
         int width  = 0;
         int height = 0;
