@@ -34,7 +34,7 @@ protected:
   virtual void create_tags(Glib::RefPtr<Gtk::TextBuffer>& refBuffer);
   virtual void insert_text(Glib::RefPtr<Gtk::TextBuffer>& refBuffer);
   virtual void attach_widgets(Gtk::TextView& text_view);
-  virtual bool find_anchor(Gtk::TextIter& iter);
+  virtual bool find_anchor(Gtk::TextBuffer::iterator& iter);
 
   //Signal handlers:
   virtual void on_button_clicked();
@@ -99,14 +99,13 @@ Example_TextView::~Example_TextView()
 void Example_TextView::create_tags(Glib::RefPtr<Gtk::TextBuffer>& refBuffer)
 {
   /* Create a bunch of tags. Note that it's also possible to
-   * create tags with gtk_text_tag_new() then add them to the
+   * create tags with Gtk::TextTag::create() then add them to the
    * tag table for the buffer, refBuffer->create_tag() is
    * just a convenience function. Also note that you don't have
-   * to give tags a name; pass NULL for the name to create an
-   * anonymous tag.
+   * to give tags a name.
    *
    * In any real app, another useful optimization would be to create
-   * a GtkTextTagTable in advance, and reuse the same tag table for
+   * a Gtk::TextTagTable in advance, and reuse the same tag table for
    * all the buffers with the same tag set, instead of creating
    * new copies of the same tags for every buffer.
    *
@@ -114,10 +113,10 @@ void Example_TextView::create_tags(Glib::RefPtr<Gtk::TextBuffer>& refBuffer)
    * tag table.	 That is, tags created later that affect the same text
    * property affected by an earlier tag will override the earlier
    * tag.  You can modify tag priorities with
-   * gtk_text_tag_set_priority().
+   * Gtk::TextTag::set_priority().
    */
 
-  Glib::RefPtr<Gtk::TextTag> refTag;
+  Glib::RefPtr<Gtk::TextBuffer::Tag> refTag;
 
   refTag = refBuffer->create_tag("heading");
   refTag->property_weight().set_value(Pango::WEIGHT_BOLD);
@@ -154,7 +153,7 @@ void Example_TextView::create_tags(Glib::RefPtr<Gtk::TextBuffer>& refBuffer)
   refTag->property_left_margin().set_value(50);
   refTag->property_right_margin().set_value(50);
 
-  refBuffer->create_tag("strikethrough")->property_strikethrough().set_value(TRUE);
+  refBuffer->create_tag("strikethrough")->property_strikethrough().set_value(true);
   refBuffer->create_tag("underline")->property_underline().set_value(Pango::UNDERLINE_SINGLE);
   refBuffer->create_tag("double_underline")->property_underline().set_value(Pango::UNDERLINE_DOUBLE);
 
@@ -190,125 +189,124 @@ void Example_TextView::insert_text(Glib::RefPtr<Gtk::TextBuffer>& refBuffer)
    * iterator to point to just after the inserted text.
    */
 
-  Gtk::TextIter iter = refBuffer->get_iter_at_offset(0);
+  Gtk::TextBuffer::iterator iter = refBuffer->get_iter_at_offset(0);
 
-  refBuffer->insert(iter, "The text widget can display text with all kinds of nifty attributes. It also supports multiple views of the same buffer; this demo is showing the same buffer in two places.\n\n");
-  refBuffer->insert_with_tag(iter, "Font styles. ", "heading");
+  iter = refBuffer->insert(iter, "The text widget can display text with all kinds of nifty attributes. It also supports multiple views of the same buffer; this demo is showing the same buffer in two places.\n\n");
+  iter = refBuffer->insert_with_tag(iter, "Font styles. ", "heading");
+  iter = refBuffer->insert(iter, "For example, you can have ");
+  iter = refBuffer->insert_with_tag(iter, "italic", "italic");
 
-  refBuffer->insert(iter, "For example, you can have ");
-  refBuffer->insert_with_tag(iter, "italic", "italic");
+  iter = refBuffer->insert(iter, ", ");
+  iter = refBuffer->insert_with_tag(iter, "bold", "bold");
+  iter = refBuffer->insert(iter, ", or ");
+  iter = refBuffer->insert_with_tag(iter, "monospace (typewriter)", "monospace");
+  iter = refBuffer->insert(iter, ", or ");
+  iter = refBuffer->insert_with_tag(iter, "big", "big");
+  iter = refBuffer->insert(iter, " text. ");
+  iter = refBuffer->insert(iter, "It's best not to hardcode specific text sizes; you can use relative sizes as with CSS, such as ");
+  iter = refBuffer->insert_with_tag(iter, "xx-small", "xx-small");
+  iter = refBuffer->insert(iter, " or ");
+  iter = refBuffer->insert_with_tag(iter, "x-large", "x-large");
+  iter = refBuffer->insert(iter, " to ensure that your program properly adapts if the user changes the default font size.\n\n");
 
-  refBuffer->insert(iter, ", ");
-  refBuffer->insert_with_tag(iter, "bold", "bold");
-  refBuffer->insert(iter, ", or ");
-  refBuffer->insert_with_tag(iter, "monospace (typewriter)", "monospace");
-  refBuffer->insert(iter, ", or ");
-  refBuffer->insert_with_tag(iter, "big", "big");
-  refBuffer->insert(iter, " text. ");
-  refBuffer->insert(iter, "It's best not to hardcode specific text sizes; you can use relative sizes as with CSS, such as ");
-  refBuffer->insert_with_tag(iter, "xx-small", "xx-small");
-  refBuffer->insert(iter, " or ");
-  refBuffer->insert_with_tag(iter, "x-large", "x-large");
-  refBuffer->insert(iter, " to ensure that your program properly adapts if the user changes the default font size.\n\n");
+  iter = refBuffer->insert_with_tag(iter, "Colors. ", "heading");
 
-  refBuffer->insert_with_tag(iter, "Colors. ", "heading");
-
-  refBuffer->insert(iter, "Colors such as ");
-  refBuffer->insert_with_tag(iter, "a blue foreground", "blue_foreground");
-  refBuffer->insert(iter, " or ");
-  refBuffer->insert_with_tag(iter, "a red background", "red_background");
-  refBuffer->insert(iter, " or even ");
+  iter = refBuffer->insert(iter, "Colors such as ");
+  iter = refBuffer->insert_with_tag(iter, "a blue foreground", "blue_foreground");
+  iter = refBuffer->insert(iter, " or ");
+  iter = refBuffer->insert_with_tag(iter, "a red background", "red_background");
+  iter = refBuffer->insert(iter, " or even ");
 
 
   typedef const char* type_constpch;
   {
     type_constpch tag_names[] = {"red_background", "background_stipple", 0};
-    refBuffer->insert_with_tags_by_name(iter, "a stippled red background", tag_names);
+    iter = refBuffer->insert_with_tags_by_name(iter, "a stippled red background", tag_names);
   }
 
-  refBuffer->insert(iter, " or ");
+  iter = refBuffer->insert(iter, " or ");
 
   {
     type_constpch tag_names[] = {"blue_foreground", "red_background", "foreground_stipple", 0};
-    refBuffer->insert_with_tags_by_name(iter, "a stippled blue foreground on solid red background", tag_names);
+    iter = refBuffer->insert_with_tags_by_name(iter, "a stippled blue foreground on solid red background", tag_names);
   }
 
-  refBuffer->insert(iter, " (select that to read it) can be used.\n\n");
+  iter = refBuffer->insert(iter, " (select that to read it) can be used.\n\n");
 
-  refBuffer->insert_with_tag(iter, "Underline, strikethrough, and rise. ", "heading");
+  iter = refBuffer->insert_with_tag(iter, "Underline, strikethrough, and rise. ", "heading");
 
-  refBuffer->insert_with_tag(iter, "Strikethrough", "strikethrough");
-  refBuffer->insert(iter, ", ");
-  refBuffer->insert_with_tag(iter, "underline", "underline");
-  refBuffer->insert(iter, ", ");
-  refBuffer->insert_with_tag(iter, "double underline", "double_underline");
-  refBuffer->insert(iter, ", ");
-  refBuffer->insert_with_tag(iter, "superscript", "superscript");
-  refBuffer->insert(iter, ", and ");
-  refBuffer->insert_with_tag(iter, "subscript", "subscript");
-  refBuffer->insert(iter, " are all supported.\n\n");
+  iter = refBuffer->insert_with_tag(iter, "Strikethrough", "strikethrough");
+  iter = refBuffer->insert(iter, ", ");
+  iter = refBuffer->insert_with_tag(iter, "underline", "underline");
+  iter = refBuffer->insert(iter, ", ");
+  iter = refBuffer->insert_with_tag(iter, "double underline", "double_underline");
+  iter = refBuffer->insert(iter, ", ");
+  iter = refBuffer->insert_with_tag(iter, "superscript", "superscript");
+  iter = refBuffer->insert(iter, ", and ");
+  iter = refBuffer->insert_with_tag(iter, "subscript", "subscript");
+  iter = refBuffer->insert(iter, " are all supported.\n\n");
 
-  refBuffer->insert_with_tag(iter, "Images. ", "heading");
+  iter = refBuffer->insert_with_tag(iter, "Images. ", "heading");
 
-  refBuffer->insert(iter, "The buffer can have images in it: ");
-  refBuffer->insert_pixbuf(iter, refPixbuf);
-  refBuffer->insert_pixbuf(iter, refPixbuf);
-  refBuffer->insert_pixbuf(iter, refPixbuf);
-  refBuffer->insert(iter, " for example.\n\n");
+  iter = refBuffer->insert(iter, "The buffer can have images in it: ");
+  iter = refBuffer->insert_pixbuf(iter, refPixbuf);
+  iter = refBuffer->insert_pixbuf(iter, refPixbuf);
+  iter = refBuffer->insert_pixbuf(iter, refPixbuf);
+  iter = refBuffer->insert(iter, " for example.\n\n");
 
-  refBuffer->insert_with_tag(iter, "Spacing. ", "heading");
+  iter = refBuffer->insert_with_tag(iter, "Spacing. ", "heading");
 
-  refBuffer->insert(iter, "You can adjust the amount of space before each line.\n");
+  iter = refBuffer->insert(iter, "You can adjust the amount of space before each line.\n");
 
   {
     type_constpch tag_names[] = {"big_gap_before_line", "wide_margins", 0};
-    refBuffer->insert_with_tags_by_name(iter,
+    iter = refBuffer->insert_with_tags_by_name(iter,
   					    "This line has a whole lot of space before it.\n", tag_names);
-    refBuffer->insert_with_tags_by_name(iter,
+    iter = refBuffer->insert_with_tags_by_name(iter,
   					    "You can also adjust the amount of space after each line; this line has a whole lot of space after it.\n", tag_names);
   }
 
   {
     type_constpch tag_names[] = {"double_spaced_line", "wide_margins", 0};
-    refBuffer->insert_with_tags_by_name(iter,
+    iter = refBuffer->insert_with_tags_by_name(iter,
   					    "You can also adjust the amount of space between wrapped lines; this line has extra space between each wrapped line in the same paragraph. To show off wrapping, some filler text: the quick brown fox jumped over the lazy dog. Blah blah blah blah blah blah blah blah blah.\n",
   					    tag_names);
   }
 
-  refBuffer->insert(iter, "Also note that those lines have extra-wide margins.\n\n");
+  iter = refBuffer->insert(iter, "Also note that those lines have extra-wide margins.\n\n");
 
-  refBuffer->insert_with_tag(iter, "Editability. ", "heading");
+  iter = refBuffer->insert_with_tag(iter, "Editability. ", "heading");
 
-  refBuffer->insert_with_tag(iter,
+  iter = refBuffer->insert_with_tag(iter,
 					    "This line is 'locked down' and can't be edited by the user - just try it! You can't delete this line.\n\n",
 					    "not_editable");
 
-  refBuffer->insert_with_tag(iter, "Wrapping. ", "heading");
+  iter = refBuffer->insert_with_tag(iter, "Wrapping. ", "heading");
 
-  refBuffer->insert(iter,
+  iter = refBuffer->insert(iter,
 			  "This line (and most of the others in this buffer) is word-wrapped, using the proper Unicode algorithm. Word wrap should work in all scripts and languages that GTK+ supports. Let's make this a long paragraph to demonstrate: blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah\n\n");
 
-  refBuffer->insert_with_tag(iter,
+  iter = refBuffer->insert_with_tag(iter,
 					    "This line has character-based wrapping, and can wrap between any two character glyphs. Let's make this a long paragraph to demonstrate: blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah\n\n",
 					    "char_wrap");
 
-  refBuffer->insert_with_tag(iter,
+  iter = refBuffer->insert_with_tag(iter,
 					    "This line has all wrapping turned off, so it makes the horizontal scrollbar appear.\n\n\n",
 					    "no_wrap");
 
-  refBuffer->insert_with_tag(iter, "Justification. ", "heading");
+  iter = refBuffer->insert_with_tag(iter, "Justification. ", "heading");
 
-  refBuffer->insert_with_tag(iter, "\nThis line has center justification.\n", "center");
+  iter = refBuffer->insert_with_tag(iter, "\nThis line has center justification.\n", "center");
 
-  refBuffer->insert_with_tag(iter, "This line has right justification.\n", "right_justify");
+  iter = refBuffer->insert_with_tag(iter, "This line has right justification.\n", "right_justify");
 
-  refBuffer->insert_with_tag(iter,
+  iter = refBuffer->insert_with_tag(iter,
 					    "\nThis line has big wide margins. Text text text text text text text text text text text text text text text text text text text text text text text text text text text text text text text text text text text text.\n",
 					    "wide_margins");
 
-  refBuffer->insert_with_tag(iter, "Internationalization. ", "heading");
+  iter = refBuffer->insert_with_tag(iter, "Internationalization. ", "heading");
 	
-  refBuffer->insert(iter,
+  iter = refBuffer->insert(iter,
       "You can put all sorts of Unicode text in the buffer.\n\nGerman (Deutsch S\xC3\xBC""d) "
       "Gr\xC3\xBC\xC3\x9F Gott\nGreek (\xCE\x95\xCE\xBB\xCE\xBB\xCE\xB7\xCE\xBD\xCE\xB9\xCE\xBA"
       "\xCE\xAC) \xCE\x93\xCE\xB5\xCE\xB9\xCE\xAC \xCF\x83\xCE\xB1\xCF\x82\nHebrew\t\xD7\xA9\xD7"
@@ -316,8 +314,8 @@ void Example_TextView::insert_text(Glib::RefPtr<Gtk::TextBuffer>& refBuffer)
       "properly handles bidirectional text, word wrapping, DOS/UNIX/Unicode paragraph separators, "
       "grapheme boundaries, and so on using the Pango internationalization framework.\n");
 
-  refBuffer->insert(iter, "Here's a word-wrapped quote in a right-to-left language:\n");
-  refBuffer->insert_with_tag(iter,
+  iter = refBuffer->insert(iter, "Here's a word-wrapped quote in a right-to-left language:\n");
+  iter = refBuffer->insert_with_tag(iter,
       "\xD9\x88\xD9\x82\xD8\xAF \xD8\xA8\xD8\xAF\xD8\xA3 \xD8\xAB\xD9\x84\xD8\xA7\xD8\xAB "
       "\xD9\x85\xD9\x86 \xD8\xA3\xD9\x83\xD8\xAB\xD8\xB1 \xD8\xA7\xD9\x84\xD9\x85\xD8\xA4"
       "\xD8\xB3\xD8\xB3\xD8\xA7\xD8\xAA \xD8\xAA\xD9\x82\xD8\xAF\xD9\x85\xD8\xA7 \xD9\x81\xD9\x8A "
@@ -342,32 +340,32 @@ void Example_TextView::insert_text(Glib::RefPtr<Gtk::TextBuffer>& refBuffer)
       "\xD8\xA7.\n\n",
       "rtl_quote");
 
-  refBuffer->insert(iter, "You can put widgets in the buffer: Here's a button: ");
+  iter = refBuffer->insert(iter, "You can put widgets in the buffer: Here's a button: ");
 
   Glib::RefPtr<Gtk::TextChildAnchor> refAnchor = refBuffer->create_child_anchor(iter);
-  refBuffer->insert(iter, " and a menu: ");
+  iter = refBuffer->insert(refBuffer->end(), " and a menu: ");
+  refAnchor = refBuffer->create_child_anchor(iter); //TODO: Maybe this should be a method of the Iterator.
+  iter = refBuffer->insert(refBuffer->end(), " and a scale: ");
   refAnchor = refBuffer->create_child_anchor(iter);
-  refBuffer->insert(iter, " and a scale: ");
+  iter = refBuffer->insert(refBuffer->end(), " and an animation: ");
   refAnchor = refBuffer->create_child_anchor(iter);
-  refBuffer->insert(iter, " and an animation: ");
+  iter = refBuffer->insert(refBuffer->end(), " finally a text entry: ");
   refAnchor = refBuffer->create_child_anchor(iter);
-  refBuffer->insert(iter, " finally a text entry: ");
-  refAnchor = refBuffer->create_child_anchor(iter);
-  refBuffer->insert(iter, ".\n");
+  iter = refBuffer->insert(refBuffer->end(), ".\n");
 
   refBuffer->insert(iter, "\n\nThis demo doesn't demonstrate all the GtkTextBuffer features; it leaves out, for example: invisible/hidden text (doesn't work in GTK 2, but planned), tab stops, application-drawn areas on the sides of the widget for displaying breakpoints and such...");
 
   // Apply word_wrap tag to whole buffer
-  Gtk::TextIter start, end;
+  Gtk::TextBuffer::iterator start, end;
   refBuffer->get_bounds(start, end);
   refBuffer->apply_tag_by_name("word_wrap", start, end);
 }
 
-bool Example_TextView::find_anchor(Gtk::TextIter& iter)
+bool Example_TextView::find_anchor(Gtk::TextBuffer::iterator& iter)
 {
-  while (iter.forward_char())
+  while(++iter)
   {
-    if (iter.get_child_anchor())
+    if(iter.get_child_anchor())
       return true;
   }
   return false;
@@ -376,10 +374,10 @@ bool Example_TextView::find_anchor(Gtk::TextIter& iter)
 void Example_TextView::attach_widgets(Gtk::TextView& text_view)
 {
   Glib::RefPtr<Gtk::TextBuffer> refBuffer = text_view.get_buffer();
-  Gtk::TextIter iter = refBuffer->get_start_iter();
+  Gtk::TextBuffer::iterator iter = refBuffer->begin();
 
   int i = 0;
-  while (find_anchor (iter))
+  while(find_anchor(iter)) //previously created with create_child_anchor().
   {
     Glib::RefPtr<Gtk::TextChildAnchor> refAnchor = iter.get_child_anchor();
     Gtk::Widget* pWidget = 0;
@@ -396,8 +394,8 @@ void Example_TextView::attach_widgets(Gtk::TextView& text_view)
       Gtk::Menu* pMenu = Gtk::manage( new Gtk::Menu() );
       MenuList items = pMenu->items();
       items.push_back(MenuElem("Option 1"));
-      items.push_back(MenuElem("Option 1"));
-      items.push_back(MenuElem("Option 1"));
+      items.push_back(MenuElem("Option 2"));
+      items.push_back(MenuElem("Option 3"));
 
       Gtk::OptionMenu* pOptionMenu = Gtk::manage( new Gtk::OptionMenu() );
       pOptionMenu->set_menu(*pMenu);
@@ -445,11 +443,11 @@ Window_EasterEgg::Window_EasterEgg()
   set_default_size(300, 400);
 
   Glib::RefPtr<Gtk::TextBuffer> refBuffer = Gtk::TextBuffer::create();
-  Gtk::TextIter iter = refBuffer->get_start_iter();
+  Gtk::TextBuffer::iterator iter = refBuffer->end();
 
-  refBuffer->insert(iter, "This buffer is shared by a set of nested text views.\n Nested view:\n");
+  iter = refBuffer->insert(iter, "This buffer is shared by a set of nested text views.\n Nested view:\n");
   Glib::RefPtr<Gtk::TextChildAnchor> refAnchor = refBuffer->create_child_anchor(iter);
-  refBuffer->insert(iter, "\nDon't do this in real applications, please.\n");
+  refBuffer->insert(refBuffer->end(), "\nDon't do this in real applications, please.\n");
 
   m_pTextView = Gtk::manage( new Gtk::TextView(refBuffer) );
 
