@@ -1,4 +1,4 @@
-//$Id: radar.cc,v 1.4 2002/07/19 15:59:03 murrayc Exp $ -*- c++ -*-
+//$Id: radar.cc,v 1.2 2003/03/22 21:30:46 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -39,7 +39,9 @@
 #include <pangomm/fontdescription.h>
 
 const double DEG2RAD = 3.1415928 / 180.0;
-
+#ifndef M_PI
+#define M_PI 3.14159265359
+#endif /* M_PI */
 
 // PPI Plan Position Indicator: radar screen
 class PPI : public Gtk::DrawingArea
@@ -123,7 +125,7 @@ void PPI::on_realize()
 }
 
 
-bool PPI::on_expose_event(GdkEventExpose* e)
+bool PPI::on_expose_event(GdkEventExpose*)
 {
   // we need a ref to the gdkmm window
   Glib::RefPtr<Gdk::Window> window = get_window();
