@@ -31,13 +31,18 @@
 #include <gdkmm/window.h>
 #include <gdkmm/pixbuf.h>
 #include <gdkmm/pixbufanimation.h>
+#include <gdkmm/pixbufformat.h>
 #include <gdkmm/pixbufloader.h>
 #include <gdkmm/pixmap.h>
 #include <gdkmm/bitmap.h>
 #include <gdkmm/image.h>
 #include <gdkmm/cursor.h>
 #include <gdkmm/rectangle.h>
+#include <gdkmm/display.h>
+#include <gdkmm/displaymanager.h>
+#include <gdkmm/screen.h>
 #include <gdkmm/general.h>
 
+
 #endif /* _GDKMM_GDKMM_H_ */
 
