@@ -1,6 +1,6 @@
 #ifndef _GTKMM_TREEMODELCOLUMN_H
 #define _GTKMM_TREEMODELCOLUMN_H
-/* $Id: treemodelcolumn.h,v 1.7 2002/07/10 18:22:52 murrayc Exp $ */
+/* $Id: treemodelcolumn.h,v 1.2 2003/01/22 12:10:08 murrayc Exp $ */
 
 /* Copyright (c) 2002 The gtkmm Development Team
  *
@@ -25,7 +25,7 @@
 #include <vector>
 #include <gtkmmconfig.h>
 
-GTKMM_USING_STD(vector)
+GLIBMM_USING_STD(vector)
 
 
 namespace Gtk
