@@ -1,4 +1,4 @@
-/* $Id: generate_defs_gtk.cc,v 1.5 2002/06/20 22:03:10 daniel Exp $ */
+/* $Id: generate_defs_gtk.cc,v 1.9 2003/11/01 17:02:39 murrayc Exp $ */
 
 /* generate_defs_gtk.cc
  *
@@ -19,7 +19,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "generate_extra_defs.h"
+#include "glibmm_generate_extra_defs/generate_extra_defs.h"
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
@@ -27,15 +27,31 @@ int main (int argc, char *argv[])
 {
   gtk_init(&argc, &argv);
 
-  std::cout << get_defs( ATK_TYPE_HYPERLINK)
-            << get_defs( ATK_TYPE_OBJECT )
-            << get_defs( ATK_TYPE_REGISTRY)
-            << get_defs( ATK_TYPE_RELATION)
-            << get_defs( ATK_TYPE_RELATION_SET)
-            << get_defs( ATK_TYPE_STATE_SET)
+  void *const g_class_atk_no_op_object = g_type_class_ref(ATK_TYPE_NO_OP_OBJECT);
 
-            << get_defs( GDK_TYPE_COLORMAP )
+  std::cout << get_defs( ATK_TYPE_HYPERLINK )
+            << get_defs( ATK_TYPE_OBJECT )
+            << get_defs( ATK_TYPE_COMPONENT )
+            << get_defs( ATK_TYPE_ACTION )
+            << get_defs( ATK_TYPE_EDITABLE_TEXT )
+            << get_defs( ATK_TYPE_IMAGE )
+            << get_defs( ATK_TYPE_SELECTION )
+            << get_defs( ATK_TYPE_TABLE )
+            << get_defs( ATK_TYPE_TEXT )
+            << get_defs( ATK_TYPE_VALUE )
+            << get_defs( ATK_TYPE_REGISTRY )
+            << get_defs( ATK_TYPE_RELATION )
+            << get_defs( ATK_TYPE_RELATION_SET )
+            << get_defs( ATK_TYPE_STATE_SET );
+
+  g_type_class_unref(g_class_atk_no_op_object);
+
+  std::cout << get_defs( GDK_TYPE_COLORMAP )
             << get_defs( GDK_TYPE_DRAG_CONTEXT )
+            << get_defs( GDK_TYPE_DISPLAY )
+#if !defined(G_OS_WIN32)
+            << get_defs( GDK_TYPE_DISPLAY_MANAGER )
+#endif /* G_OS_WIN32 */
             << get_defs( GDK_TYPE_DRAWABLE )
             << get_defs( GDK_TYPE_GC )
             << get_defs( GDK_TYPE_IMAGE )
@@ -43,11 +59,13 @@ int main (int argc, char *argv[])
             << get_defs( GDK_TYPE_PIXBUF_ANIMATION )
             << get_defs( GDK_TYPE_PIXBUF_LOADER )
             << get_defs( GDK_TYPE_PIXMAP )
+            << get_defs( GDK_TYPE_SCREEN )
             << get_defs( GDK_TYPE_VISUAL )
             << get_defs( GDK_TYPE_WINDOW )
 
             << get_defs( GTK_TYPE_ACCEL_GROUP )
             << get_defs( GTK_TYPE_ACCEL_LABEL )
+            << get_defs( GTK_TYPE_ACTION )
             << get_defs( GTK_TYPE_ADJUSTMENT )
             << get_defs( GTK_TYPE_ALIGNMENT)
             << get_defs( GTK_TYPE_ARROW )
@@ -59,22 +77,30 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_CALENDAR )
             << get_defs( GTK_TYPE_CHECK_BUTTON )
             << get_defs( GTK_TYPE_CHECK_MENU_ITEM )
-            << get_defs( GTK_TYPE_CLIST )
+            << get_defs( GTK_TYPE_CLIST ) /* Deprecated */
             << get_defs( GTK_TYPE_CELL_RENDERER )
             << get_defs( GTK_TYPE_CELL_RENDERER_TEXT )
             << get_defs( GTK_TYPE_CELL_RENDERER_TOGGLE )
             << get_defs( GTK_TYPE_CELL_RENDERER_PIXBUF )
+            << get_defs( GTK_TYPE_COLOR_BUTTON )   
             << get_defs( GTK_TYPE_COLOR_SELECTION )
-            << get_defs( GTK_TYPE_COMBO )
+            << get_defs( GTK_TYPE_COMBO ) /* Deprecated */
+            << get_defs( GTK_TYPE_COMBO_BOX ) 
             << get_defs( GTK_TYPE_CONTAINER )
-            << get_defs( GTK_TYPE_CTREE )
+            << get_defs( GTK_TYPE_CTREE ) /* Deprecated */
             << get_defs( GTK_TYPE_CURVE )
             << get_defs( GTK_TYPE_DIALOG )
             << get_defs( GTK_TYPE_DRAWING_AREA )
             << get_defs( GTK_TYPE_ENTRY )
+            << get_defs( GTK_TYPE_ENTRY_COMPLETION )
             << get_defs( GTK_TYPE_EVENT_BOX )
-            << get_defs( GTK_TYPE_FILE_SELECTION )
+            << get_defs( GTK_TYPE_EXPANDER )
+            << get_defs( GTK_TYPE_FILE_FILTER )
+            << get_defs( GTK_TYPE_FILE_CHOOSER_DIALOG )
+            << get_defs( GTK_TYPE_FILE_CHOOSER_WIDGET )                        
+            << get_defs( GTK_TYPE_FILE_SELECTION ) /* Deprecated */
             << get_defs( GTK_TYPE_FIXED )
+            << get_defs( GTK_TYPE_FONT_BUTTON )            
             << get_defs( GTK_TYPE_FONT_SELECTION )
             << get_defs( GTK_TYPE_FONT_SELECTION_DIALOG )
             << get_defs( GTK_TYPE_FRAME )
@@ -98,13 +124,15 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_OPTION_MENU )
             << get_defs( GTK_TYPE_PANED )
             << get_defs( GTK_TYPE_PIXMAP )
-#if !defined(_WIN32)
+#if !defined(G_OS_WIN32)
             << get_defs( GTK_TYPE_PLUG )
-#endif
+#endif /* G_OS_WIN32 */
             << get_defs( GTK_TYPE_PREVIEW )
             << get_defs( GTK_TYPE_PROGRESS )
             << get_defs( GTK_TYPE_PROGRESS_BAR )
             << get_defs( GTK_TYPE_RADIO_BUTTON )
+            << get_defs( GTK_TYPE_RADIO_TOOL_BUTTON )
+            << get_defs( GTK_TYPE_RADIO_ACTION )            
             << get_defs( GTK_TYPE_RADIO_MENU_ITEM )
             << get_defs( GTK_TYPE_RANGE )
             << get_defs( GTK_TYPE_RULER )
@@ -112,11 +140,12 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_SCROLLBAR )
             << get_defs( GTK_TYPE_SCROLLED_WINDOW )
             << get_defs( GTK_TYPE_SEPARATOR )
+            << get_defs( GTK_TYPE_SEPARATOR_TOOL_ITEM )
             << get_defs( GTK_TYPE_SETTINGS )
             << get_defs( GTK_TYPE_SIZE_GROUP )
-#if !defined(_WIN32)
+#if !defined(G_OS_WIN32)
             << get_defs( GTK_TYPE_SOCKET )
-#endif
+#endif /* G_OS_WIN32 */
             << get_defs( GTK_TYPE_SPIN_BUTTON )
             << get_defs( GTK_TYPE_STATUSBAR )
             << get_defs( GTK_TYPE_STYLE )
@@ -125,16 +154,22 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_TIPS_QUERY )
             << get_defs( GTK_TYPE_TOGGLE_BUTTON )
             << get_defs( GTK_TYPE_TOOLBAR )
+            << get_defs( GTK_TYPE_TOOL_ITEM )
+            << get_defs( GTK_TYPE_TOOL_BUTTON )                          
             << get_defs( GTK_TYPE_TEXT_BUFFER )
             << get_defs( GTK_TYPE_TEXT_MARK )
             << get_defs( GTK_TYPE_TEXT_TAG )
             << get_defs( GTK_TYPE_TEXT_TAG_TABLE )
             << get_defs( GTK_TYPE_TEXT_VIEW )
+            << get_defs( GTK_TYPE_TOGGLE_ACTION )            
+            << get_defs( GTK_TYPE_TOGGLE_TOOL_BUTTON )  
             << get_defs( GTK_TYPE_TOOLTIPS )
             << get_defs( GTK_TYPE_TREE_SELECTION )
+            << get_defs( GTK_TYPE_TREE_MODEL_FILTER )            
             << get_defs( GTK_TYPE_TREE_STORE )
             << get_defs( GTK_TYPE_TREE_VIEW )
             << get_defs( GTK_TYPE_TREE_VIEW_COLUMN )
+            << get_defs( GTK_TYPE_UI_MANAGER )
             << get_defs( GTK_TYPE_VIEWPORT )
             << get_defs( GTK_TYPE_WIDGET )
             << get_defs( GTK_TYPE_WINDOW );
